@@ -129,7 +129,7 @@ void SieveEditorMainWindow::setupActions()
     mUploadScript->setText(i18n("Upload"));
     mUploadScript->setEnabled(false);
 
-    QAction *act = new QAction(i18n("Add Sieve Server..."), this);
+    auto act = new QAction(i18n("Add Sieve Server..."), this);
     connect(act, &QAction::triggered, this, &SieveEditorMainWindow::slotAddServerSieve);
     ac->addAction(QStringLiteral("add_server_sieve"), act);
 
@@ -190,13 +190,6 @@ void SieveEditorMainWindow::setupActions()
     mShareAction->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
     purposeMenu->setEditorWidget(mMainWidget->sieveEditorMainWidget());
 
-    mShareHotNewStuffAction = new QAction(i18n("Share Script..."), this);
-    connect(mShareHotNewStuffAction, &QAction::triggered, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotShareScript);
-    ac->addAction(QStringLiteral("share_hot_new_stuff_script"), mShareHotNewStuffAction);
-    const QStringList overlays = QStringList() << QStringLiteral("list-add");
-    mShareHotNewStuffAction->setIcon(QIcon(new KIconEngine(QStringLiteral("get-hot-new-stuff"), KIconLoader::global(), overlays)));
-    mShareHotNewStuffAction->setEnabled(false);
-
     mSpellCheckAction = new QAction(i18n("Check Spelling..."), this);
     connect(mSpellCheckAction, &QAction::triggered, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotCheckSpelling);
     ac->addAction(QStringLiteral("check_spelling"), mSpellCheckAction);
@@ -371,7 +364,6 @@ void SieveEditorMainWindow::slotUpdateActions()
     mImportAction->setEnabled(hasPage);
     mShareAction->setEnabled(hasPage && !mNetworkIsDown);
 
-    mShareHotNewStuffAction->setEnabled(hasPage && !mNetworkIsDown);
     mSpellCheckAction->setEnabled(editActionEnabled);
     mCheckSyntaxAction->setEnabled(editActionEnabled && !mNetworkIsDown);
     mCreateRulesGraphicallyAction->setEnabled(editActionEnabled);
